==> MLPAstats_0.5-7.tar.gz: MLPAstats/data/BRCA.R <==
`BRCAcontrols` <-
structure(list(id =  c("control1", "control2", 
"control3", "control4", "control5"), replicate = c(1, 
1, 1, 1, 1), C5q31 = c(2204L, 1803L, 2206L, 2423L, 2191L), C6p21 = c(1758L, 
1555L, 1811L, 2022L, 1887L), BRCA1Ex1A = c(2432L, 1895L, 2464L, 
2843L, 2864L), BRCA1Ex1B = c(2484L, 2298L, 2644L, 2982L, 2957L
), BRCA1Ex2 = c(2332L, 2194L, 2502L, 2748L, 2730L), BRCA1Ex3 = c(1255L, 
819L, 1294L, 1508L, 1314L), BRCA1Ex5 = c(1667L, 1334L, 1836L, 
2026L, 1776L), C15q21 = c(1150L, 976L, 1227L, 1359L, 1243L), 
    BRCA1Ex6 = c(1331L, 970L, 1422L, 1491L, 1437L), BRCA1Ex7 = c(920L, 
    635L, 957L, 1080L, 982L), BRCA1Ex8 = c(1102L, 822L, 1202L, 
    1273L, 1183L), BRCA1Ex9 = c(1305L, 1024L, 1404L, 1577L, 1417L
    ), BRCA1Ex10 = c(1350L, 893L, 1456L, 1610L, 1466L), C2q14 = c(1083L, 
    683L, 1211L, 1374L, 1131L), `BRCA1Ex11-1` = c(818L, 581L, 
    878L, 990L, 890L), `BRCA1Ex11-2` = c(879L, 596L, 996L, 1105L, 
    913L), BRCA1Ex12 = c(1018L, 666L, 1106L, 1250L, 1065L), BRCA1Ex13 = c(882L, 
    556L, 1005L, 1039L, 857L), BRCA1Ex14 = c(888L, 590L, 1005L, 
    1088L, 838L), C12p12 = c(965L, 685L, 1064L, 1235L, 902L), 
    BRCA1Ex15 = c(865L, 646L, 939L, 1108L, 853L), BRCA1Ex16 = c(695L, 
    392L, 778L, 873L, 599L), BRCA1Ex17 = c(627L, 460L, 695L, 
    846L, 620L), BRCA1Ex18 = c(925L, 686L, 1044L, 1181L, 938L
    ), BRCA1Ex19 = c(912L, 637L, 1066L, 1289L, 1030L), C4q26 = c(748L, 
    494L, 823L, 944L, 603L), BRCA1Ex20 = c(714L, 490L, 826L, 
    980L, 745L), BRCA1Ex21 = c(579L, 460L, 686L, 788L, 526L), 
    BRCA1Ex22 = c(588L, 437L, 673L, 746L, 562L), BRCA1Ex23 = c(565L, 
    341L, 635L, 743L, 564L), BRCA1Ex24 = c(549L, 299L, 640L, 
    779L, 493L), C11p13 = c(680L, 421L, 815L, 931L, 699L), C12p13 = c(532L, 
    273L, 593L, 702L, 520L), C3p21 = c(714L, 372L, 846L, 985L, 
    646L)), .Names = c("id", "replicate", "C5q31", "C6p21", "BRCA1Ex1A", 
"BRCA1Ex1B", "BRCA1Ex2", "BRCA1Ex3", "BRCA1Ex5", "C15q21", "BRCA1Ex6", 
"BRCA1Ex7", "BRCA1Ex8", "BRCA1Ex9", "BRCA1Ex10", "C2q14", "BRCA1Ex11-1", 
"BRCA1Ex11-2", "BRCA1Ex12", "BRCA1Ex13", "BRCA1Ex14", "C12p12", 
"BRCA1Ex15", "BRCA1Ex16", "BRCA1Ex17", "BRCA1Ex18", "BRCA1Ex19", 
"C4q26", "BRCA1Ex20", "BRCA1Ex21", "BRCA1Ex22", "BRCA1Ex23", 
"BRCA1Ex24", "C11p13", "C12p13", "C3p21"), row.names = c("1", 
"2", "3", "4", "5"), class = "data.frame")
`BRCAtests` <-
structure(list(id =  c("test1", "test10", "test2", "test3", "test4", 
"test5", "test6", "test7", "test8", "test9"), 
    replicate = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1), C5q31 = c(2191L, 
    1593L, 2763L, 2551L, 1967L, 2324L, 1967L, 1803L, 1803L, 1803L
    ), C6p21 = c(1825L, 1246L, 2331L, 1986L, 1645L, 1854L, 1645L, 
    1555L, 1555L, 1555L), BRCA1Ex1A = c(2712L, 2242L, 3111L, 
    3139L, 2868L, 2984L, 2868L, 1895L, 1895L, 1895L), BRCA1Ex1B = c(3199L, 
    2668L, 3400L, 3471L, 3488L, 3332L, 3488L, 2298L, 2298L, 2298L
    ), BRCA1Ex2 = c(2647L, 2288L, 3142L, 3089L, 2690L, 2842L, 
    2690L, 2194L, 2194L, 2194L), BRCA1Ex3 = c(1240L, 1075L, 1552L, 
    1523L, 1295L, 1367L, 1295L, 819L, 819L, 819L), BRCA1Ex5 = c(1883L, 
    1399L, 2291L, 2226L, 1852L, 1960L, 1852L, 1334L, 1334L, 1334L
    ), C15q21 = c(1204L, 805L, 1540L, 1430L, 1186L, 1234L, 1186L, 
    976L, 976L, 976L), BRCA1Ex6 = c(1375L, 958L, 1572L, 1535L, 
    1352L, 1547L, 1352L, 970L, 970L, 970L), BRCA1Ex7 = c(920L, 
    619L, 1022L, 1084L, 920L, 981L, 920L, 635L, 635L, 635L), 
    BRCA1Ex8 = c(1173L, 882L, 1392L, 1413L, 1054L, 1264L, 1054L, 
    822L, 822L, 822L), BRCA1Ex9 = c(1421L, 1126L, 1654L, 1710L, 
    1416L, 1524L, 1416L, 1024L, 1024L, 1024L), BRCA1Ex10 = c(1474L, 
    1136L, 1621L, 1678L, 1300L, 1544L, 1300L, 893L, 893L, 893L
    ), C2q14 = c(1107L, 993L, 1325L, 1382L, 976L, 1232L, 976L, 
    683L, 683L, 683L), `BRCA1Ex11-1` = c(897L, 655L, 1025L, 1030L, 
    810L, 978L, 810L, 581L, 581L, 581L), `BRCA1Ex11-2` = c(928L, 
    704L, 1140L, 1086L, 664L, 969L, 664L, 596L, 596L, 596L), 
    BRCA1Ex12 = c(1083L, 903L, 1327L, 1332L, 1016L, 1204L, 1016L, 
    666L, 666L, 666L), BRCA1Ex13 = c(868L, 567L, 1013L, 964L, 
    923L, 1431L, 923L, 556L, 556L, 556L), BRCA1Ex14 = c(910L, 
    713L, 1096L, 1154L, 796L, 1026L, 796L, 590L, 590L, 590L), 
    C12p12 = c(921L, 669L, 1164L, 1158L, 782L, 1089L, 782L, 685L, 
    685L, 685L), BRCA1Ex15 = c(870L, 666L, 1041L, 1058L, 701L, 
    929L, 701L, 646L, 646L, 646L), BRCA1Ex16 = c(668L, 572L, 
    828L, 839L, 522L, 759L, 522L, 392L, 392L, 392L), BRCA1Ex17 = c(614L, 
    477L, 747L, 751L, 415L, 699L, 415L, 460L, 460L, 460L), BRCA1Ex18 = c(977L, 
    802L, 1153L, 1204L, 857L, 1063L, 857L, 686L, 686L, 686L), 
    BRCA1Ex19 = c(1016L, 872L, 1224L, 1319L, 910L, 1142L, 910L, 
    637L, 637L, 637L), C4q26 = c(718L, 537L, 861L, 870L, 557L, 
    789L, 557L, 494L, 494L, 494L), BRCA1Ex20 = c(859L, 693L, 
    954L, 1062L, 655L, 882L, 655L, 490L, 490L, 490L), BRCA1Ex21 = c(619L, 
    527L, 750L, 741L, 464L, 622L, 464L, 460L, 460L, 460L), BRCA1Ex22 = c(543L, 
    469L, 755L, 749L, 460L, 687L, 460L, 437L, 437L, 437L), BRCA1Ex23 = c(581L, 
    466L, 712L, 741L, 470L, 660L, 470L, 341L, 341L, 341L), BRCA1Ex24 = c(535L, 
    435L, 684L, 698L, 421L, 578L, 421L, 299L, 299L, 299L), C11p13 = c(654L, 
    542L, 826L, 913L, 538L, 759L, 538L, 421L, 421L, 421L), C12p13 = c(531L, 
    491L, 616L, 681L, 362L, 618L, 362L, 273L, 273L, 273L), C3p21 = c(681L, 
    557L, 859L, 894L, 495L, 788L, 495L, 372L, 372L, 372L)), .Names = c("id", 
"replicate", "C5q31", "C6p21", "BRCA1Ex1A", "BRCA1Ex1B", "BRCA1Ex2", 
"BRCA1Ex3", "BRCA1Ex5", "C15q21", "BRCA1Ex6", "BRCA1Ex7", "BRCA1Ex8", 
"BRCA1Ex9", "BRCA1Ex10", "C2q14", "BRCA1Ex11-1", "BRCA1Ex11-2", 
"BRCA1Ex12", "BRCA1Ex13", "BRCA1Ex14", "C12p12", "BRCA1Ex15", 
"BRCA1Ex16", "BRCA1Ex17", "BRCA1Ex18", "BRCA1Ex19", "C4q26", 
"BRCA1Ex20", "BRCA1Ex21", "BRCA1Ex22", "BRCA1Ex23", "BRCA1Ex24", 
"C11p13", "C12p13", "C3p21"), row.names = c("1", "2", "3", "4", 
"5", "6", "7", "8", "9", "10"), class = "data.frame")
`probes.control` <-
c(1, 2, 8, 14, 20, 26, 32, 33, 34)
`size` <-
c(127, 136, 148, 157, 166, 175, 184, 196, 208, 217, 226, 235, 
244, 256, 268, 277, 286, 295, 304, 316, 328, 337, 346, 355, 364, 
376, 388, 397, 406, 415, 424, 436, 445, 454)

==> MLPAstats_0.5-9.tar.gz: MLPAstats/data/BRCA.R <==
`BRCAcontrols` <-
structure(list(id =  c("control1", "control2", 
"control3", "control4", "control5"), replicate = c(1, 
1, 1, 1, 1), C5q31 = c(2204L, 1803L, 2206L, 2423L, 2191L), C6p21 = c(1758L, 
1555L, 1811L, 2022L, 1887L), BRCA1Ex1A = c(2432L, 1895L, 2464L, 
2843L, 2864L), BRCA1Ex1B = c(2484L, 2298L, 2644L, 2982L, 2957L
), BRCA1Ex2 = c(2332L, 2194L, 2502L, 2748L, 2730L), BRCA1Ex3 = c(1255L, 
819L, 1294L, 1508L, 1314L), BRCA1Ex5 = c(1667L, 1334L, 1836L, 
2026L, 1776L), C15q21 = c(1150L, 976L, 1227L, 1359L, 1243L), 
    BRCA1Ex6 = c(1331L, 970L, 1422L, 1491L, 1437L), BRCA1Ex7 = c(920L, 
    635L, 957L, 1080L, 982L), BRCA1Ex8 = c(1102L, 822L, 1202L, 
    1273L, 1183L), BRCA1Ex9 = c(1305L, 1024L, 1404L, 1577L, 1417L
    ), BRCA1Ex10 = c(1350L, 893L, 1456L, 1610L, 1466L), C2q14 = c(1083L, 
    683L, 1211L, 1374L, 1131L), `BRCA1Ex11-1` = c(818L, 581L, 
    878L, 990L, 890L), `BRCA1Ex11-2` = c(879L, 596L, 996L, 1105L, 
    913L), BRCA1Ex12 = c(1018L, 666L, 1106L, 1250L, 1065L), BRCA1Ex13 = c(882L, 
    556L, 1005L, 1039L, 857L), BRCA1Ex14 = c(888L, 590L, 1005L, 
    1088L, 838L), C12p12 = c(965L, 685L, 1064L, 1235L, 902L), 
    BRCA1Ex15 = c(865L, 646L, 939L, 1108L, 853L), BRCA1Ex16 = c(695L, 
    392L, 778L, 873L, 599L), BRCA1Ex17 = c(627L, 460L, 695L, 
    846L, 620L), BRCA1Ex18 = c(925L, 686L, 1044L, 1181L, 938L
    ), BRCA1Ex19 = c(912L, 637L, 1066L, 1289L, 1030L), C4q26 = c(748L, 
    494L, 823L, 944L, 603L), BRCA1Ex20 = c(714L, 490L, 826L, 
    980L, 745L), BRCA1Ex21 = c(579L, 460L, 686L, 788L, 526L), 
    BRCA1Ex22 = c(588L, 437L, 673L, 746L, 562L), BRCA1Ex23 = c(565L, 
    341L, 635L, 743L, 564L), BRCA1Ex24 = c(549L, 299L, 640L, 
    779L, 493L), C11p13 = c(680L, 421L, 815L, 931L, 699L), C12p13 = c(532L, 
    273L, 593L, 702L, 520L), C3p21 = c(714L, 372L, 846L, 985L, 
    646L)), .Names = c("id", "replicate", "C5q31", "C6p21", "BRCA1Ex1A", 
"BRCA1Ex1B", "BRCA1Ex2", "BRCA1Ex3", "BRCA1Ex5", "C15q21", "BRCA1Ex6", 
"BRCA1Ex7", "BRCA1Ex8", "BRCA1Ex9", "BRCA1Ex10", "C2q14", "BRCA1Ex11-1", 
"BRCA1Ex11-2", "BRCA1Ex12", "BRCA1Ex13", "BRCA1Ex14", "C12p12", 
"BRCA1Ex15", "BRCA1Ex16", "BRCA1Ex17", "BRCA1Ex18", "BRCA1Ex19", 
"C4q26", "BRCA1Ex20", "BRCA1Ex21", "BRCA1Ex22", "BRCA1Ex23", 
"BRCA1Ex24", "C11p13", "C12p13", "C3p21"), row.names = c("1", 
"2", "3", "4", "5"), class = "data.frame")
`BRCAcases` <-
structure(list(id =  c("case01", "case10", "case02", "case03", "case04", 
"case05", "case06", "case07", "case08", "case09"), 
    replicate = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1), C5q31 = c(2191L, 
    1593L, 2763L, 2551L, 1967L, 2324L, 1967L, 1803L, 1803L, 1803L
    ), C6p21 = c(1825L, 1246L, 2331L, 1986L, 1645L, 1854L, 1645L, 
    1555L, 1555L, 1555L), BRCA1Ex1A = c(2712L, 2242L, 3111L, 
    3139L, 2868L, 2984L, 2868L, 1895L, 1895L, 1895L), BRCA1Ex1B = c(3199L, 
    2668L, 3400L, 3471L, 3488L, 3332L, 3488L, 2298L, 2298L, 2298L
    ), BRCA1Ex2 = c(2647L, 2288L, 3142L, 3089L, 2690L, 2842L, 
    2690L, 2194L, 2194L, 2194L), BRCA1Ex3 = c(1240L, 1075L, 1552L, 
    1523L, 1295L, 1367L, 1295L, 819L, 819L, 819L), BRCA1Ex5 = c(1883L, 
    1399L, 2291L, 2226L, 1852L, 1960L, 1852L, 1334L, 1334L, 1334L
    ), C15q21 = c(1204L, 805L, 1540L, 1430L, 1186L, 1234L, 1186L, 
    976L, 976L, 976L), BRCA1Ex6 = c(1375L, 958L, 1572L, 1535L, 
    1352L, 1547L, 1352L, 970L, 970L, 970L), BRCA1Ex7 = c(920L, 
    619L, 1022L, 1084L, 920L, 981L, 920L, 635L, 635L, 635L), 
    BRCA1Ex8 = c(1173L, 882L, 1392L, 1413L, 1054L, 1264L, 1054L, 
    822L, 822L, 822L), BRCA1Ex9 = c(1421L, 1126L, 1654L, 1710L, 
    1416L, 1524L, 1416L, 1024L, 1024L, 1024L), BRCA1Ex10 = c(1474L, 
    1136L, 1621L, 1678L, 1300L, 1544L, 1300L, 893L, 893L, 893L
    ), C2q14 = c(1107L, 993L, 1325L, 1382L, 976L, 1232L, 976L, 
    683L, 683L, 683L), `BRCA1Ex11-1` = c(897L, 655L, 1025L, 1030L, 
    810L, 978L, 810L, 581L, 581L, 581L), `BRCA1Ex11-2` = c(928L, 
    704L, 1140L, 1086L, 664L, 969L, 664L, 596L, 596L, 596L), 
    BRCA1Ex12 = c(1083L, 903L, 1327L, 1332L, 1016L, 1204L, 1016L, 
    666L, 666L, 666L), BRCA1Ex13 = c(868L, 567L, 1013L, 964L, 
    923L, 1431L, 923L, 556L, 556L, 556L), BRCA1Ex14 = c(910L, 
    713L, 1096L, 1154L, 796L, 1026L, 796L, 590L, 590L, 590L), 
    C12p12 = c(921L, 669L, 1164L, 1158L, 782L, 1089L, 782L, 685L, 
    685L, 685L), BRCA1Ex15 = c(870L, 666L, 1041L, 1058L, 701L, 
    929L, 701L, 646L, 646L, 646L), BRCA1Ex16 = c(668L, 572L, 
    828L, 839L, 522L, 759L, 522L, 392L, 392L, 392L), BRCA1Ex17 = c(614L, 
    477L, 747L, 751L, 415L, 699L, 415L, 460L, 460L, 460L), BRCA1Ex18 = c(977L, 
    802L, 1153L, 1204L, 857L, 1063L, 857L, 686L, 686L, 686L), 
    BRCA1Ex19 = c(1016L, 872L, 1224L, 1319L, 910L, 1142L, 910L, 
    637L, 637L, 637L), C4q26 = c(718L, 537L, 861L, 870L, 557L, 
    789L, 557L, 494L, 494L, 494L), BRCA1Ex20 = c(859L, 693L, 
    954L, 1062L, 655L, 882L, 655L, 490L, 490L, 490L), BRCA1Ex21 = c(619L, 
    527L, 750L, 741L, 464L, 622L, 464L, 460L, 460L, 460L), BRCA1Ex22 = c(543L, 
    469L, 755L, 749L, 460L, 687L, 460L, 437L, 437L, 437L), BRCA1Ex23 = c(581L, 
    466L, 712L, 741L, 470L, 660L, 470L, 341L, 341L, 341L), BRCA1Ex24 = c(535L, 
    435L, 684L, 698L, 421L, 578L, 421L, 299L, 299L, 299L), C11p13 = c(654L, 
    542L, 826L, 913L, 538L, 759L, 538L, 421L, 421L, 421L), C12p13 = c(531L, 
    491L, 616L, 681L, 362L, 618L, 362L, 273L, 273L, 273L), C3p21 = c(681L, 
    557L, 859L, 894L, 495L, 788L, 495L, 372L, 372L, 372L)), .Names = c("id", 
"replicate", "C5q31", "C6p21", "BRCA1Ex1A", "BRCA1Ex1B", "BRCA1Ex2", 
"BRCA1Ex3", "BRCA1Ex5", "C15q21", "BRCA1Ex6", "BRCA1Ex7", "BRCA1Ex8", 
"BRCA1Ex9", "BRCA1Ex10", "C2q14", "BRCA1Ex11-1", "BRCA1Ex11-2", 
"BRCA1Ex12", "BRCA1Ex13", "BRCA1Ex14", "C12p12", "BRCA1Ex15", 
"BRCA1Ex16", "BRCA1Ex17", "BRCA1Ex18", "BRCA1Ex19", "C4q26", 
"BRCA1Ex20", "BRCA1Ex21", "BRCA1Ex22", "BRCA1Ex23", "BRCA1Ex24", 
"C11p13", "C12p13", "C3p21"), row.names = c("1", "2", "3", "4", 
"5", "6", "7", "8", "9", "10"), class = "data.frame")
`reference.probes` <-
c(1, 2, 8, 14, 20, 26, 32, 33, 34)
`size` <-
c(127, 136, 148, 157, 166, 175, 184, 196, 208, 217, 226, 235, 
244, 256, 268, 277, 286, 295, 304, 316, 328, 337, 346, 355, 364, 
376, 388, 397, 406, 415, 424, 436, 445, 454)
